betty.warnings module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.warnings module

Provide utilities for raising warnings.

exception betty.warnings.BettyDeprecationWarning

  Bases: `DeprecationWarning`

  Raised for deprecated Betty functionality.

betty.warnings.deprecate(message: str, stacklevel: int = 1)

  Raise a Betty deprecation warning.

class betty.warnings.deprecated

  Bases: `deprecated`

  Decorate a class, function, or overload to indicate that it is deprecated.

  This is identical to `typing_extensions.deprecated`, but raises a Betty deprecation warning.

  __init__(message: str, stacklevel: int = 1)